# Check.tcl - itcl megawidget for choosing options using a label and checkbuttons
#              (uses blt_table to arrange the buttons in rows and columns)
#
# Copyright (C) 1994 Allan Brighton (allan@piano.sta.sub.org)
#


itcl_class Check {
    inherit FrameWidget

    
    # return the current value of this option

    method get {} {
	global $this.choice
	set value {}
	foreach i $choice {
	    if {[set $this.choice($i)]} {
		lappend value $i
	    }
	}
	return $value
    }

    
    # return true if the value has changed since it was last 
    # configured or read

    method changed {} {
	global $this.choice
	set v {}
	foreach i $choice {
	    if {[set $this.choice($i)]} {
		lappend v $i
	    }
	}
	return [expr {"$v" != "$value"}]
    }

    # configure the individual buttons by name

    method itemconfig {name args} {
	eval "$but_($name) config $args"
    }

    
    constructor {config} {
	FrameWidget::constructor
	global $this.choice

	if {"$text" != ""} {
	    pack [label $this.label -text $text] \
		    -side $side_ -ipadx 1m -fill x
	}

	pack [set f [frame $this.rowcols]] -side $side_ -padx $padx -pady $pady -fill x
	blt_table $f

	set row 0
	set col 0
	set i 0
	set n [llength $choice]

	# determine how many rows and columns
	if {$rows != 0} {
	    set cols [expr $n/$rows+1]
	} elseif {$cols != 0} {
	    set rows [expr $n/$cols+1]
	} elseif {"$layout" == "horizontal"} {
	    set rows 1
	    set cols $n
	} else {
	    set rows $n
	    set cols 1
	}

	for {set row 0} {$row < $rows} {incr row} {
	    for {set col 0} {$col < $cols} {incr col} {
		set name [lindex $choice $i]
		set $this.choice($name) 0
		set but_($name) \
		    [checkbutton $f.check$i \
			 -text $name \
			 -variable $this.choice($name) \
			 -command $command \
			 -state $state \
			 -anchor w]
		blt_table $f $but_($name) $row,$col -fill x
		if {[incr i] == $n} {
		    break
		}
	    }
	    if {$i == $n} {
		break
	    }
	}


	#  Explicitly handle config's that may have been ignored earlier
	foreach attr $config {
	    config -$attr [set $attr]
	}
    }


    # public member variables


    # label for option
    public text {}

    # list of choices to display as ON, all others are then OFF
    public value {} {
	global $this.choice
	if {[info exists $this.choice]} {
	    foreach i [array names $this.choice] {
		set $this.choice($i) 0
	    }
	}
	foreach i $value {
	    set $this.choice($i) 1
	}
    }

    # list of choices
    public choice {}

    # command to run when the list of selected items changes
    public command {} {
	if {"$command" != ""} {
	    append command [format { [%s get]} $this]
	}
    }
    
    # determines position for label and default layout for buttons
    public layout {horizontal} {
	if {"$layout" == "horizontal"} {
	    set side_ left
	} else {
	    set side_ top
	}
    }

    # max number of rows to display (0 for unlimited) 
    # note: specify either -rows OR -cols, but not both
    public rows 0

    # max number of columns to display (0 for unlimited)
    # note: specify either -rows OR -cols, but not both
    public cols 0

    # button states: normal, disabled
    public state {normal} {
	if {[info exists but_]} {
	    foreach i [array names but_] {
		$but_($i) config -state $state
	    }
	}
    }


    # set the width for  displaying the label
    public labelWidth {} {
	if {[winfo exists $this.label]} {
	    $this.label config -width $labelWidth
	}
    }
    
    # set the label anchor
    public anchor {w} {
	if {[winfo exists $this.label]} {
	    $this.label config -anchor $anchor
	}
    }

    # packing options for first button
    public padx {0}
    public pady {0}

    
    # protected members
    
    # array(name) of button widgets
    protected but_

    # pack option
    protected side_ {left}
}

